@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2000 Free Software Foundation, Inc.
+ * Copyright (C) 1999-2001 Free Software Foundation, Inc.
  * This file is part of the GNU LIBICONV Library.
  *
  * The GNU LIBICONV Library is free software; you can redistribute it
@@ -117,5 +117,5 @@ cp1129_wctomb (conv_t conv, unsigned char *r, ucs4_t wc, int n)
     *r = c;
     return 1;
   }
-  return RET_ILSEQ;
+  return RET_ILUNI;
 }
